==> astsa_1.13.tar.gz: astsa/man/cardox.Rd <==
\name{cardox}
\alias{cardox}
\docType{data}
\title{Monthly Carbon Dioxide Levels at Mauna Loa
}
\description{
Monthly mean carbon dioxide (in ppm) measured at Mauna Loa Observatory, Hawaii. 
This is an update to \code{co2} in the datasets package.
}
\format{
  The format is:
 Time-Series [1:729] from March, 1958 to November 2018: 315.71 317.45 317.50 317.10  ...
}
\details{
 The carbon dioxide data measured as the mole fraction in dry air, on Mauna Loa constitute the longest record of direct measurements of CO2 in the atmosphere. They were started by C. David Keeling of the Scripps Institution of Oceanography in March of 1958 at a facility of the National Oceanic and Atmospheric Administration. NOAA started its own CO2 measurements in May of 1974, and they have run in parallel with those made by Scripps since then. Data are reported as a dry mole fraction defined as the number of molecules of carbon dioxide divided by the number of molecules of dry air multiplied by one million (ppm). 
}
\source{\kbd{https://gml.noaa.gov/ccgg/trends/}
}
\references{You can find demonstrations of  astsa capabilities at  
\href{https://github.com/nickpoison/astsa/blob/master/fun_with_astsa/fun_with_astsa.md}{FUN WITH ASTSA}.

The most recent version of the package can be found  at \url{https://github.com/nickpoison/astsa/}.

In addition, the News and ChangeLog files are at  \url{https://github.com/nickpoison/astsa/blob/master/NEWS.md}.

The webpages for the texts are \url{https://www.stat.pitt.edu/stoffer/tsa4/} and \url{https://www.stat.pitt.edu/stoffer/tsda/}.   
}
\keyword{datasets}

==> astsa_2.2.tar.gz: astsa/man/cardox.Rd <==
\name{cardox}
\alias{cardox}
\docType{data}
\title{Monthly Carbon Dioxide Levels at Mauna Loa
} 
\description{
Monthly mean carbon dioxide (in ppm) measured at Mauna Loa Observatory, Hawaii. 
This is an update to \code{co2} in the datasets package.
}
\format{
  The format is:
 Time-Series  [1:781] from 1958 to 2023: 316 317 318 317 316   ...
}
\details{
 The carbon dioxide data measured as the mole fraction in dry air, on Mauna Loa constitute the longest record of direct measurements of CO2 in the atmosphere. They were started by C. David Keeling of the Scripps Institution of Oceanography in March of 1958 at a facility of the National Oceanic and Atmospheric Administration. NOAA started its own CO2 measurements in May of 1974, and they have run in parallel with those made by Scripps since then. Data are reported as a dry mole fraction defined as the number of molecules of carbon dioxide divided by the number of molecules of dry air multiplied by one million (ppm).

Due to the eruption of the Mauna Loa Volcano, measurements from Mauna Loa Observatory were suspended as of Nov. 29, 2022. Observations starting in December 2022 are from a site at the Maunakea Observatories, approximately 21 miles north of the Mauna Loa Observatory. 
}
\source{\kbd{https://gml.noaa.gov/ccgg/trends/}
}
\references{You can find demonstrations of  astsa capabilities at  
\href{https://github.com/nickpoison/astsa/blob/master/fun_with_astsa/fun_with_astsa.md}{FUN WITH ASTSA}.

The most recent version of the package can be found  at \url{https://github.com/nickpoison/astsa/}.

In addition, the News and ChangeLog files are at  \url{https://github.com/nickpoison/astsa/blob/master/NEWS.md}.

The webpages for the texts and some help on using R for time series analysis can be found at
 \url{https://nickpoison.github.io/}.   
}
\keyword{datasets}
